documentationtools.make_ligeti_example_lilypond_file
====================================================

.. autofunction:: abjad.tools.documentationtools.make_ligeti_example_lilypond_file.make_ligeti_example_lilypond_file
